@@ -1,8 +1,8 @@
 /*
 **  OSSP var - Variable Expansion
-**  Copyright (c) 2001-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2003 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2001-2003 Cable & Wireless Deutschland (http://www.cw.com/de/)
+**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2004 The OSSP Project (http://www.ossp.org/)
+**  Copyright (c) 2001-2004 Cable & Wireless (http://www.cw.com/)
 **
 **  This file is part of OSSP var, a variable expansion
 **  library which can be found at http://www.ossp.org/pkg/lib/var/.
@@ -32,6 +32,7 @@
 #include "config.h"
 #endif
 
+/* required system headers */
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
@@ -44,11 +45,13 @@
 #else
 #  include <regex.h>
 #endif
-#include "var.h"
 #if defined(HAVE_DMALLOC_H) && defined(WITH_DMALLOC)
-#include "dmalloc.h"
+#include <dmalloc.h>
 #endif
 
+/* required internal headers */
+#include "var.h"
+
 /* unique library identifier */
 const char var_id[] = "OSSP var";
 
@@ -126,7 +129,7 @@ var_mvxprintf(
     int n;
     int bytes;
 
-    if (format == NULL || ap == NULL)
+    if (format == NULL)
         return -1;
     bytes = 0;
     while (*format != '\0') {
@@ -214,7 +217,7 @@ var_mvsnprintf(
     int n;
     var_mvsnprintf_cb_t ctx;
 
-    if (format == NULL || ap == NULL)
+    if (format == NULL)
         return -1;
     if (buffer != NULL && bufsize == 0)
         return -1;
@@ -2467,7 +2470,7 @@ var_config(
         case VAR_CONFIG_CB_VALUE: {
             var_cb_value_t fct;
             void *ctx;
-            fct = (var_cb_value_t)va_arg(ap, void *);
+            fct = (var_cb_value_t)va_arg(ap, var_cb_value_t);
             ctx = (void *)va_arg(ap, void *);
             var->cb_value_fct = fct;
             var->cb_value_ctx = ctx;
@@ -2476,7 +2479,7 @@ var_config(
         case VAR_CONFIG_CB_OPERATION: {
             var_cb_operation_t fct;
             void *ctx;
-            fct = (var_cb_operation_t)va_arg(ap, void *);
+            fct = (var_cb_operation_t)va_arg(ap, var_cb_operation_t);
             ctx = (void *)va_arg(ap, void *);
             var->cb_operation_fct = fct;
             var->cb_operation_ctx = ctx;
@@ -2580,7 +2583,7 @@ var_expand(
 
     /* post-processing */
     if (rc >= 0) {
-        /* always NUL-terminate output for convinience reasons
+        /* always NUL-terminate output for convenience reasons
            but do not count the NUL-terminator in the length */
         if (!tokenbuf_append(&output, "\0", 1)) {
             tokenbuf_free(&output);
@@ -2621,9 +2624,9 @@ var_formatv(
         return VAR_RC(VAR_ERR_INVALID_ARGUMENT);
 
     /* determine formatting buffer length */
-    apbak = ap;
+    va_copy(apbak, ap);
     nBuf = var_mvsnprintf(NULL, 0, fmt, ap);
-    ap = apbak;
+    va_copy(ap, apbak);
     if (nBuf == -1)
         return VAR_RC(VAR_ERR_FORMATTING_FAILURE);
 
@@ -2719,7 +2722,7 @@ static const char *var_errors[] = {
     "formatting failure"                                       /* VAR_ERR_FORMATTING_FAILURE */
 };
 
-/* transslate a return code into its corresponding descriptive text */
+/* translate a return code into its corresponding descriptive text */
 var_rc_t var_strerror(var_t *var, var_rc_t rc, char **str)
 {
     if (str == NULL)
