@@ -1,8 +1,8 @@
 /*
 **  OSSP var -- Variable Expansion
-**  Copyright (c) 2001-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2003 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2001-2003 Cable & Wireless Deutschland (http://www.cw.com/de/)
+**  Copyright (c) 2001-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2004 The OSSP Project (http://www.ossp.org/)
+**  Copyright (c) 2001-2004 Cable & Wireless (http://www.cw.com/)
 **
 **  This file is part of OSSP var, a variable expansion
 **  library which can be found at http://www.ossp.org/pkg/lib/var/.
@@ -29,13 +29,14 @@
 */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <errno.h>
 #include <ctype.h>
 
 #include "config.h"
 #if defined(HAVE_DMALLOC_H) && defined(WITH_DMALLOC)
-#include "dmalloc.h"
+#include <dmalloc.h>
 #endif
 
 #include "var.h"
@@ -317,7 +318,7 @@ TS_TEST(test_format)
     var_t *var;
     char *err;
     char *fmt;
-    char *exp;
+    char *expect;
     char *got;
 
     ts_test_check(TS_CTX, "create environment");
@@ -334,15 +335,15 @@ TS_TEST(test_format)
 
     /* check trivial formatting */
     fmt = "foo";
-    exp = "foo";
+    expect = "foo";
     ts_test_check(TS_CTX, "formatting \"%s\"", fmt);
     if ((rc = var_format(var, &got, 1, fmt)) != VAR_OK) {
         var_strerror(var, rc, &err);
         ts_test_fail(TS_CTX, "var_format: %s (%d)", err, rc);
         return;
     }
-    if (strcmp(got, exp) != 0) {
-        ts_test_fail(TS_CTX, "var_format: expected \"%s\", got \"%s\"\n", exp, got);
+    if (strcmp(got, expect) != 0) {
+        ts_test_fail(TS_CTX, "var_format: expected \"%s\", got \"%s\"\n", expect, got);
         free(got);
         return;
     }
@@ -350,15 +351,15 @@ TS_TEST(test_format)
 
     /* check real formatting */
     fmt = "foo<%s><%d><%c>quux";
-    exp = "foo<bar><123><x>quux";
+    expect = "foo<bar><123><x>quux";
     ts_test_check(TS_CTX, "formatting \"%s\"", fmt);
     if ((rc = var_format(var, &got, 1, fmt, "bar", 123, 'x')) != VAR_OK) {
         var_strerror(var, rc, &err);
         ts_test_fail(TS_CTX, "var_format: %s (%d)", err, rc);
         return;
     }
-    if (strcmp(got, exp) != 0) {
-        ts_test_fail(TS_CTX, "var_format: expected \"%s\", got \"%s\"\n", exp, got);
+    if (strcmp(got, expect) != 0) {
+        ts_test_fail(TS_CTX, "var_format: expected \"%s\", got \"%s\"\n", expect, got);
         free(got);
         return;
     }
@@ -366,15 +367,15 @@ TS_TEST(test_format)
 
     /* check combined formatting and expansion */
     fmt = "foo<${ARRAY[%d]}>bar";
-    exp = "foo<entry1>bar";
+    expect = "foo<entry1>bar";
     ts_test_check(TS_CTX, "formatting \"%s\"", fmt);
     if ((rc = var_format(var, &got, 1, fmt, 1)) != VAR_OK) {
         var_strerror(var, rc, &err);
         ts_test_fail(TS_CTX, "var_format: %s (%d)", err, rc);
         return;
     }
-    if (strcmp(got, exp) != 0) {
-        ts_test_fail(TS_CTX, "var_format: expected \"%s\", got \"%s\"\n", exp, got);
+    if (strcmp(got, expect) != 0) {
+        ts_test_fail(TS_CTX, "var_format: expected \"%s\", got \"%s\"\n", expect, got);
         free(got);
         return;
     }
